@@ -156,6 +156,7 @@ typedef enum {
 	CD_SENSOR_KIND_COLORHUG,	/* Since: 0.1.15 */
 	CD_SENSOR_KIND_SPYDER2,		/* Since: 0.1.16 */
 	CD_SENSOR_KIND_SPYDER3,		/* Since: 0.1.16 */
+	CD_SENSOR_KIND_COLORHUG_SPECTRO,/* Since: 0.1.24 */
 	CD_SENSOR_KIND_LAST
 } CdSensorKind;
 
@@ -204,6 +205,38 @@ typedef enum {
 	CD_STANDARD_SPACE_LAST
 } CdStandardSpace;
 
+/**
+ * CdProfileWarning:
+ * @CD_PROFILE_WARNING_NONE: No error is found
+ * @CD_PROFILE_WARNING_DESCRIPTION_MISSING: The description is missing or of zero length
+ * @CD_PROFILE_WARNING_COPYRIGHT_MISSING: The copyright is missing or of zero length
+ * @CD_PROFILE_WARNING_VCGT_NON_MONOTONIC: The video card gamma table is not monotonic
+ * @CD_PROFILE_WARNING_SCUM_DOT: Lab 100, 0, 0 does not map to RGB 255,255,255
+ * @CD_PROFILE_WARNING_GRAY_AXIS_INVALID: There is significant a/b for gray
+ * @CD_PROFILE_WARNING_GRAY_AXIS_NON_MONOTONIC: The gray ramp is not monotonic
+ * @CD_PROFILE_WARNING_PRIMARIES_INVALID: One or more of the primaries are invalid
+ * @CD_PROFILE_WARNING_PRIMARIES_UNLIKELY: One or more of the primaries are outside of ROMM RGB
+ * @CD_PROFILE_WARNING_WHITEPOINT_INVALID: RGB 255,255,255 does not return D50
+ *
+ * The warning about the profile. Profiles with warnings can still be
+ * used, but may be of limited use.
+ **/
+typedef enum {
+	CD_PROFILE_WARNING_NONE,			/* Since: 0.1.25 */
+	CD_PROFILE_WARNING_DESCRIPTION_MISSING,		/* Since: 0.1.25 */
+	CD_PROFILE_WARNING_COPYRIGHT_MISSING,		/* Since: 0.1.25 */
+	CD_PROFILE_WARNING_VCGT_NON_MONOTONIC,		/* Since: 0.1.25 */
+	CD_PROFILE_WARNING_SCUM_DOT,			/* Since: 0.1.25 */
+	CD_PROFILE_WARNING_GRAY_AXIS_INVALID,		/* Since: 0.1.25 */
+	CD_PROFILE_WARNING_GRAY_AXIS_NON_MONOTONIC,	/* Since: 0.1.25 */
+	CD_PROFILE_WARNING_PRIMARIES_INVALID,		/* Since: 0.1.25 */
+	CD_PROFILE_WARNING_PRIMARIES_NON_ADDITIVE,	/* Since: 0.1.25 */
+	CD_PROFILE_WARNING_PRIMARIES_UNLIKELY,		/* Since: 0.1.25 */
+	CD_PROFILE_WARNING_WHITEPOINT_INVALID,		/* Since: 0.1.25 */
+	/*< private >*/
+	CD_PROFILE_WARNING_LAST
+} CdProfileWarning;
+
 /* defined in org.freedesktop.ColorManager.xml */
 #define CD_CLIENT_PROPERTY_DAEMON_VERSION	"DaemonVersion"
 
@@ -240,6 +273,7 @@ typedef enum {
 #define CD_PROFILE_METADATA_CONNECTION_TYPE_DVI		"dvi"		/* Since: 0.1.16 */
 #define CD_PROFILE_METADATA_CONNECTION_TYPE_HDMI	"hdmi"		/* Since: 0.1.16 */
 #define CD_PROFILE_METADATA_CONNECTION_TYPE_DISPLAYPORT	"displayport"	/* Since: 0.1.16 */
+#define CD_PROFILE_METADATA_LICENSE		"License"		/* Since: 0.1.25 */
 
 /* defined in org.freedesktop.ColorManager.Profile.xml */
 #define CD_PROFILE_PROPERTY_FILENAME		"Filename"
@@ -255,9 +289,13 @@ typedef enum {
 #define CD_PROFILE_PROPERTY_ID			"ProfileId"
 #define CD_PROFILE_PROPERTY_SCOPE		"Scope"
 #define CD_PROFILE_PROPERTY_OWNER		"Owner"
+#define CD_PROFILE_PROPERTY_WARNINGS		"Warnings"		/* Since: 0.1.25 */
 
 /* defined in metadata-spec.txt */
 #define CD_DEVICE_METADATA_XRANDR_NAME		"XRANDR_name"
+#define CD_DEVICE_METADATA_OUTPUT_PRIORITY	"OutputPriority"
+#define CD_DEVICE_METADATA_OUTPUT_PRIORITY_PRIMARY	"primary"
+#define CD_DEVICE_METADATA_OUTPUT_PRIORITY_SECONDARY	"secondary"
 
 /* defined in org.freedesktop.ColorManager.Device.xml */
 #define CD_DEVICE_PROPERTY_MODEL		"Model"
@@ -274,6 +312,7 @@ typedef enum {
 #define CD_DEVICE_PROPERTY_ID			"DeviceId"
 #define CD_DEVICE_PROPERTY_SCOPE		"Scope"
 #define CD_DEVICE_PROPERTY_OWNER		"Owner"
+#define CD_DEVICE_PROPERTY_SEAT			"Seat"
 #define CD_DEVICE_PROPERTY_PROFILING_INHIBITORS	"ProfilingInhibitors"
 
 const gchar	*cd_device_kind_to_string		(CdDeviceKind		 kind_enum);
@@ -298,6 +337,8 @@ const gchar	*cd_sensor_cap_to_string		(CdSensorCap		 sensor_cap);
 CdSensorCap	 cd_sensor_cap_from_string		(const gchar		*sensor_cap);
 const gchar	*cd_standard_space_to_string		(CdStandardSpace	 standard_space);
 CdStandardSpace	 cd_standard_space_from_string		(const gchar		*standard_space);
+const gchar	*cd_profile_warning_to_string		(CdProfileWarning	 kind_enum);
+CdProfileWarning cd_profile_warning_from_string		(const gchar		*type);
 CdProfileKind	 cd_device_kind_to_profile_kind		(CdDeviceKind		 device_kind);
 
 G_END_DECLS
